@@ -5,8 +5,9 @@
 # use: ./getdisk.pl <hostname> <disk number>
 #
 # By Steven Micallef <smic@wire.net.au> on the 24/4/1999.
+# Externale bug fixed by Alon Goldberg <pyro@elapsed.net> 27/2/2000.
 
-use Net::Telnet ();
+use Net::Telnet;
 
 $hostname = $ARGV[0];
 $disk_no = $ARGV[1];
@@ -16,21 +17,14 @@ $port = 9047;
 
 $i = 0;
 
-if ($hostname eq "" || $disk_no eq "" )
-{
-  print "Usage: $0 <hostname> <disk number>\n";
-  exit;
-}
+if (!defined($disk_no)) { print "Usage: $0 <hostname> <disk number>\n"; exit }
 
 $t = new Net::Telnet ( Host => $hostname, Port => $port);
 $t->open("$hostname");
 
-do
-{
+while ($i ne $disk_no) {
   $data = $t->getline(Timeout => 40);
   $i++;
-  if ($i eq $disk_no)
-  {
-    print $data;
-  }
-} while ($i != $disk_no);
+  print $data, 0, "\n" if $i eq $disk_no;
+}
+
